@@ -58,11 +58,11 @@
 #' mean(age ~ sex & treat, data=HELPrct)
 
 #' @rdname aggregating-methods
-#' @usage mean(x, ..., na.rm=FALSE, trim=0)
+#' @usage mean(x, ..., na.rm=getOption("na.rm",FALSE), trim=0)
 
 setGeneric( 
 	"mean", 
-	function(x, ..., na.rm=FALSE, trim=0)  {
+	function(x, ..., na.rm=getOption("na.rm",FALSE), trim=0)  {
 		dots <- list(...)
 		if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
 			data <- dots[[1]]
@@ -81,12 +81,12 @@ setGeneric(
 #' @param data a data frame
 #' @export
 #' @usage
-#' \S4method{mean}{ANY}(x, ..., na.rm=FALSE, trim=0) 
+#' \S4method{mean}{ANY}(x, ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 
 setMethod(
 	'mean',
 	'ANY',
-	function(x, ..., na.rm=FALSE, trim=0) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 		base::mean( .flatten(c(x,list(...))), na.rm=na.rm, trim=trim ) 
 	
 )
@@ -95,12 +95,12 @@ setMethod(
 ### @aliases mean,numeric-method
 #' @export
 #' @usage
-#' \S4method{mean}{numeric}(x, ..., na.rm=FALSE, trim=0) 
+#' \S4method{mean}{numeric}(x, ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 
 setMethod(
 	'mean',
 	'numeric',
-	function(x, ..., na.rm=FALSE, trim=0) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 		base::mean( c(x,.flatten(list(...))), na.rm=na.rm, trim=trim ) 
 	
 )
@@ -109,11 +109,11 @@ setMethod(
 ### @aliases mean,data.frame-method
 #' @export
 #' @usage
-#' \S4method{mean}{data.frame}(x, ..., na.rm=TRUE, trim=0) 
+#' \S4method{mean}{data.frame}(x, ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 setMethod( 
 	"mean", 
 	signature=c("data.frame"),
-	function(x, ..., na.rm=TRUE, trim=0) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 		base::mean(x=x, ..., na.rm=na.rm, trim=trim)
 )
 
@@ -121,17 +121,12 @@ setMethod(
 #' @aliases mean,formula-method
 #' @export
 #' @usage
-#' \S4method{mean}{formula}(x, data=parent.frame(), ..., na.rm=TRUE, trim=0) 
+#' \S4method{mean}{formula}(x, data=parent.frame(2), ..., na.rm=getOption("na.rm",FALSE), trim=0) 
 setMethod( 
 	"mean", 
 	signature=c("formula"),
-	function(x, data=parent.frame(), ..., na.rm=TRUE, trim=0) {
-		if(FALSE &&  .is.simple.formula(x) ) {
-			return( base::mean( eval( .simple.part(x), envir=data, enclos=parent.frame()), 
-							   ..., na.rm=na.rm, trim=trim ) )
-		} else {
-			return( maggregate( x, data, FUN=base::mean, ..., na.rm=na.rm, trim=trim ) )
-		} 
+	function(x, data=parent.frame(2), ..., na.rm=getOption("na.rm",FALSE), trim=0) {
+			return( maggregate( x, data=data, FUN=base::mean, ..., na.rm=na.rm, trim=trim ) ) 
 	}
 )
 
@@ -154,10 +149,10 @@ setMethod(
 #' @export
 
 #' @rdname aggregating-methods
-#' @usage median(x, ..., na.rm=FALSE)
+#' @usage median(x, ..., na.rm=getOption("na.rm",FALSE))
 setGeneric( 
 	"median", 
-	function(x, ..., na.rm=FALSE)  {
+	function(x, ..., na.rm=getOption("na.rm",FALSE))  {
 		dots <- list(...)
 		if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
 			data <- dots[[1]]
@@ -171,11 +166,11 @@ setGeneric(
 #' @aliases median,ANY-method
 #' @export
 #' @usage
-#' \S4method{median}{ANY}(x, ..., na.rm=FALSE) 
+#' \S4method{median}{ANY}(x, ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod(
 	'median',
 	'ANY',
-	function(x, ..., na.rm=FALSE) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) 
 		stats::median( .flatten(c(x,list(...))), na.rm=na.rm ) 
 	
 )
@@ -184,11 +179,11 @@ setMethod(
 #' @aliases median,numeric-method
 #' @export
 #' @usage
-#' \S4method{median}{numeric}(x, ..., na.rm=FALSE) 
+#' \S4method{median}{numeric}(x, ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod(
 	'median',
 	'numeric',
-	function(x, ..., na.rm=FALSE) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) 
 		stats::median( c(x,.flatten(list(...))), na.rm=na.rm)
 	
 )
@@ -197,28 +192,23 @@ setMethod(
 #' @aliases median,data.frame-method
 #' @export
 #' @usage
-#' \S4method{median}{numeric}(x, ..., na.rm=FALSE) 
+#' \S4method{median}{numeric}(x, ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod( 
 	"median", 
 	signature=c("data.frame"),
-	function(x, ..., na.rm=TRUE) sapply( x, stats::median, na.rm=na.rm)
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) sapply( x, stats::median, na.rm=na.rm)
 )
 
 #' @rdname aggregating-methods
 #' @aliases median,formula-method
 #' @export
 #' @usage
-#' \S4method{median}{formula}(x, data=parent.frame(), ..., na.rm=TRUE) 
+#' \S4method{median}{formula}(x, data=parent.frame(2), ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod( 
 	"median", 
 	signature=c("formula"),
-	function(x, data=parent.frame(), ..., na.rm=TRUE) {
-		if(FALSE && .is.simple.formula(x) ) {
-			return( median( eval( .simple.part(x), data, enclos=parent.frame()), 
-							   ..., na.rm=na.rm ) )
-		} else {
-			return( maggregate( x, data, FUN=stats::median, na.rm=na.rm) )
-		} 
+	function(x, data=parent.frame(2), ..., na.rm=getOption("na.rm",FALSE)) {
+			return( maggregate( x, data, FUN=stats::median, na.rm=na.rm) ) 
 	}
 )
 
@@ -240,10 +230,10 @@ setMethod(
 #' @export
 
 #' @rdname aggregating-methods
-#' @usage sd(x, ..., na.rm=FALSE)
+#' @usage sd(x, ..., na.rm=getOption("na.rm",FALSE))
 setGeneric( 
 	"sd", 
-	function(x, ..., na.rm=FALSE)  {
+	function(x, ..., na.rm=getOption("na.rm",FALSE))  {
 		dots <- list(...)
 		if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
 			data <- dots[[1]]
@@ -257,11 +247,11 @@ setGeneric(
 #' @aliases sd,ANY-method
 #' @export
 #' @usage
-#' \S4method{sd}{ANY}(x, ..., na.rm=FALSE) 
+#' \S4method{sd}{ANY}(x, ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod(
 	'sd',
 	'ANY',
-	function(x, ..., na.rm=FALSE) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) 
 		stats::sd( .flatten(c(x,list(...))), na.rm=na.rm) 
 )
 
@@ -269,11 +259,11 @@ setMethod(
 #' @aliases sd,numeric-method
 #' @export
 #' @usage
-#' \S4method{sd}{numeric}(x, ..., na.rm=FALSE) 
+#' \S4method{sd}{numeric}(x, ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod(
 	'sd',
 	'numeric',
-	function(x, ..., na.rm=FALSE) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) 
 		stats::sd( c(x,.flatten(list(...))), na.rm=na.rm)
 	
 )
@@ -282,27 +272,23 @@ setMethod(
 #' @aliases sd,data.frame-method
 #' @export
 #' @usage
-#' \S4method{sd}{data.frame}(x, ..., na.rm=TRUE) 
+#' \S4method{sd}{data.frame}(x, ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod( 
 	"sd", 
 	signature=c("data.frame"),
-	function(x, ..., na.rm=TRUE) sapply( x, stats::sd, na.rm=na.rm)
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) sapply( x, stats::sd, na.rm=na.rm)
 )
 
 #' @rdname aggregating-methods
 #' @aliases sd,formula-method
 #' @export
 #' @usage
-#' \S4method{sd}{formula}(x, data=parent.frame(), ..., na.rm=TRUE) 
+#' \S4method{sd}{formula}(x, data=parent.frame(2), ..., na.rm=getOption("na.rm",FALSE)) 
 setMethod( 
 	"sd", 
 	signature=c("formula"),
-	function(x, data=parent.frame(), ..., na.rm=TRUE) {
-		if(FALSE && .is.simple.formula(x) ) {
-			return( sd( eval( .simple.part(x), envir=data, enclos=parent.frame()), ..., na.rm=na.rm ) )
-		} else {
+	function(x, data=parent.frame(2), ..., na.rm=getOption("na.rm",FALSE)) {
 			return( maggregate( x, data, FUN=SD, na.rm=na.rm) )
-		} 
 	}
 )
 ##########################################################################################
@@ -312,7 +298,7 @@ setMethod(
 
 	setGeneric( 
 		NAME, 
-		function(x, ..., na.rm=FALSE)  {
+		function(x, ..., na.rm=getOption("na.rm",FALSE))  {
 			dots <- list(...)
 			if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
 				data <- dots[[1]]
@@ -325,7 +311,7 @@ setMethod(
 	setMethod(
 		NAME,
 		'numeric',
-		function(x, ..., na.rm=FALSE) {
+		function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 			FUN(x, ..., na.rm=na.rm) 
 		}
 	)
@@ -334,7 +320,7 @@ setMethod(
 	setMethod( 
 		NAME, 
 		signature=c("data.frame"),
-		function(x, ..., na.rm=TRUE) {
+		function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 			sapply( x, FUN, na.rm=na.rm)
 		}
 	)
@@ -343,15 +329,10 @@ setMethod(
 	setMethod( 
 		NAME, 
 		signature=c("formula"),
-		function(x, ..., na.rm=TRUE) {
+		function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 			dots <- list(...)
 			data  <- dots[[1]]
-
-			if(FALSE && .is.simple.formula(x) ) {
-				return( FUN( eval( .simple.part(x), data, enclos=parent.frame()), na.rm=na.rm ) )
-			} else {
-				return( maggregate( x, data, FUN=FUN, na.rm=na.rm) )
-			} 
+			return( maggregate( x, data, FUN=FUN, na.rm=na.rm) )
 		}
 	)
 }
@@ -365,7 +346,7 @@ setMethod(
 # 
 setGeneric( 
 	'.Max', 
-	function(x, ..., na.rm=FALSE)  {
+	function(x, ..., na.rm=getOption("na.rm",FALSE))  {
 		dots <- list(...)
 		if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
 			data <- dots[[1]]
@@ -378,14 +359,14 @@ setGeneric(
 setMethod(
 	'.Max',
 	'ANY',
-	function(x, ..., na.rm=FALSE) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) 
 		base::max( x,..., na.rm=na.rm) 
 )
 
 setMethod(
 	'.Max',
 	'numeric',
-	function(x, ..., na.rm=FALSE) {
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 		base::max(x, ..., na.rm=na.rm) 
 	}
 )
@@ -394,7 +375,7 @@ setMethod(
 setMethod( 
 	'.Max', 
 	signature=c("data.frame"),
-	function(x, ..., na.rm=TRUE) {
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 		sapply( x, base::max, na.rm=na.rm)
 	}
 )
@@ -403,41 +384,37 @@ setMethod(
 setMethod( 
 	'.Max', 
 	signature=c("formula"),
-	function(x, ..., na.rm=TRUE) {
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 		dots <- list(...)
 		data  <- .fetchFromDots( dots, 'data', 1, 'data.frame', parent.frame())
 
-		if(FALSE && .is.simple.formula(x) ) {
-			return( base::max( eval( .simple.part(x), data, enclos=parent.frame()), na.rm=na.rm ) )
-		} else {
-			return( maggregate( x, data, FUN=base::max, na.rm=na.rm) )
-		} 
+		return( maggregate( x, data, FUN=base::max, na.rm=na.rm) )
 	}
 )
 ###############################################################
 setGeneric( 
-	'.Min', 
-	function(x, ..., na.rm=FALSE)  {
-		dots <- list(...)
-		if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
-			data <- .fetchFromDots(dots, 'data', 'data.frame', 1, NULL)
-			return(base::min(eval( substitute(x), data),  na.rm=na.rm))
-		}
-		standardGeneric('.Min')
-	}
+  '.Min', 
+  function(x, ..., na.rm=getOption("na.rm",FALSE))  {
+    dots <- list(...)
+    if ( ! .is.formula(x) && length(dots) > 0 && is.data.frame( dots[[1]] ) ) {
+      data <- dots[[1]]
+      return(base::min(eval( substitute(x), data),  na.rm=na.rm))
+    }
+    standardGeneric('.Min')
+  }
 )
 
 setMethod(
 	'.Min',
 	'ANY',
-	function(x, ..., na.rm=FALSE) 
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) 
 		base::min(x ,..., na.rm=na.rm)
 )
 
 setMethod(
 	'.Min',
 	'numeric',
-	function(x, ..., na.rm=FALSE) {
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 		base::min(x, ..., na.rm=na.rm) 
 	}
 )
@@ -446,7 +423,7 @@ setMethod(
 setMethod( 
 	'.Min', 
 	signature=c("data.frame"),
-	function(x, ..., na.rm=TRUE) {
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 		sapply( x, base::min, na.rm=na.rm)
 	}
 )
@@ -455,15 +432,10 @@ setMethod(
 setMethod( 
 	'.Min', 
 	signature=c("formula"),
-	function(x, ..., na.rm=TRUE) {
+	function(x, ..., na.rm=getOption("na.rm",FALSE)) {
 		dots <- list(...)
-		data <- .fetchFromDots(dots, 'data', 'data.frame', 1, NULL)
-
-		if(FALSE && .is.simple.formula(x) ) {
-			return( base::min( eval( .simple.part(x), data, enclos=parent.frame()), na.rm=na.rm ) )
-		} else {
-			return( maggregate( x, data, FUN=base::min, na.rm=na.rm) )
-		} 
+		data <- .fetchFromDots(dots, 'data', 'data.frame', 1, parent.frame())
+		return( maggregate( x, data, FUN=base::min, na.rm=na.rm) )
 	}
 )
 
@@ -489,14 +461,16 @@ setMethod(
 #' var(age ~ sex & treat, data=HELPrct)
 
 #' @rdname aggregating-methods
-#' @usage var(x, y=NULL, na.rm=FALSE, use='everything', data=NULL)
+#' @usage var(x, y, na.rm=getOption("na.rm",FALSE), use, data)
 setGeneric( 
 	"var", 
-	function(x, y=NULL, na.rm=FALSE, use='everything', data=NULL)  {
-		if ( is.data.frame(data) && is.name(substitute(x)) && is.name(substitute(y)) ) {
+	function(x, y=NULL, na.rm=getOption("na.rm",FALSE), use, data)  {
+		useSpecified <- !missing(use)
+		dataSpecified <- !missing(data)
+		if ( dataSpecified && is.data.frame(data) && is.name(substitute(x)) && is.name(substitute(y)) ) {
 			return( stats::var(eval( substitute(x), data), eval(substitute(y), data), na.rm=na.rm, use=use) )
 		}
-		if ( is.data.frame(data) && is.name(substitute(x)) && is.null(y) ) {
+		if ( dataSpecified && is.data.frame(data) && is.name(substitute(x)) && is.null(y) ) {
 			return( stats::var( eval( substitute(x), data), na.rm=na.rm, use=use) )
 		}
 		if ( is.data.frame(y) && is.name(substitute(x)) ) {
@@ -510,15 +484,16 @@ setGeneric(
 			data <- na.rm
 			return( stats::var(eval( substitute(x), data), use=use) )
 		}
-		if ( is.data.frame(use) && is.name(substitute(x)) && is.name(substitute(y)) ) {
+		if ( useSpecified && is.data.frame(use) && is.name(substitute(x)) && is.name(substitute(y)) ) {
 			data <- use
 			return( stats::var(eval( substitute(x), data), eval(substitute(y), data), na.rm=na.rm) )
 		}
-		if ( is.data.frame(use) && is.name(substitute(x)) && is.null(y) ) {
+		if ( useSpecified && is.data.frame(use) && is.name(substitute(x)) && is.null(y) ) {
 			data <- use
 			return( stats::var(eval( substitute(x), data), na.rm=na.rm) )
 		}
-		standardGeneric('var')
+		return(standardGeneric('var'))
+		stop("Bug alert: This line should never be reached.")
 	}
 )
 
@@ -527,11 +502,11 @@ setGeneric(
 ### @aliases var,ANY,ANY,ANY,ANY,ANY-method
 #' @export
 #' @usage
-#' \S4method{var}{ANY,ANY,ANY,ANY,ANY}(x, y, na.rm=FALSE, use='everything', data=parent.frame()) 
+#' \S4method{var}{ANY,ANY,ANY,ANY,ANY}(x, y, na.rm=getOption("na.rm",FALSE), use, data=parent.frame(2)) 
 setMethod(
 	'var',
 	c('ANY','ANY'),
-	function(x, y, na.rm=FALSE, use='everything', data=parent.frame()) 
+	function(x, y, na.rm=getOption("na.rm",FALSE), use, data=parent.frame(2)) 
 		stats::var( x, y, na.rm=na.rm, use=use) 
 )
 
@@ -539,23 +514,24 @@ setMethod(
 ### @aliases var,numeric,numeric,ANY,ANY,ANY-method
 #' @export
 #' @usage
-#' \S4method{var}{numeric,numeric,ANY,ANY,ANY}(x, y, na.rm=FALSE, use='everything', data=parent.frame()) 
+#' \S4method{var}{numeric,numeric,ANY,ANY,ANY}(x, y, na.rm=getOption("na.rm",FALSE), use, data) 
 setMethod(
 	'var',
 	c('numeric','numeric'),
-	function(x, y, na.rm=FALSE, use='everything', data=parent.frame()) 
+	function(x, y, na.rm=getOption("na.rm",FALSE), use, data) {
 		stats::var( x, y, na.rm=na.rm, use=use) 
+	}
 )
 
 #' @rdname aggregating-methods
 ### @aliases var,numeric,ANY,ANY,ANY,ANY-method
 #' @export
 #' @usage
-#' \S4method{var}{numeric,ANY,ANY,ANY,ANY}(x, y=NULL, na.rm=FALSE, use='everything', data=parent.frame()) 
+#' \S4method{var}{numeric,ANY,ANY,ANY,ANY}(x, y=NULL, na.rm=getOption("na.rm",FALSE), use, data=parent.frame(2)) 
 setMethod(
 	'var',
 	c('numeric'),
-	function(x, y=NULL, na.rm=FALSE, use='everything', data=parent.frame()) {
+	function(x, y=NULL, na.rm=getOption("na.rm",FALSE), use, data=parent.frame(2)) {
 		if (is.null(y) )
 			stats::var( x, y, na.rm=na.rm)
 		else
@@ -567,11 +543,11 @@ setMethod(
 ### @aliases var,matrix,ANY,ANY,ANY,ANY-method
 #' @export
 #' @usage
-#' \S4method{var}{matrix,ANY,ANY,ANY,ANY}(x, y, na.rm=FALSE, use='everything', data=parent.frame()) 
+#' \S4method{var}{matrix,ANY,ANY,ANY,ANY}(x, y, na.rm=getOption("na.rm",FALSE), use, data=parent.frame(2)) 
 setMethod(
 	'var',
 	c('matrix'),
-	function(x, y, na.rm=FALSE, use='everything', data=parent.frame()) 
+	function(x, y, na.rm=getOption("na.rm",FALSE), use, data=parent.frame(2)) 
 		stats::var( x, y, na.rm=na.rm, use=use) 
 )
 
@@ -579,44 +555,52 @@ setMethod(
 ### @aliases var,data.frame,ANY,ANY,ANY,ANY-method
 #' @export
 #' @usage
-#' \S4method{var}{data.frame,ANY,ANY,ANY,ANY}(x, y, na.rm=TRUE, use='everything')
+#' \S4method{var}{data.frame,ANY,ANY,ANY,ANY}(x, y, na.rm=getOption("na.rm",FALSE), use)
 setMethod( 
 	"var", 
 	signature=c("data.frame"),
-	function(x, y, na.rm=TRUE, use='everything') stats::var(x, y, na.rm=na.rm, use=use)
+	function(x, y, na.rm=getOption("na.rm",FALSE), use) stats::var(x, y, na.rm=na.rm, use=use)
 )
 
 #' @rdname aggregating-methods
 ### @aliases var,formula,missing,ANY,ANY,missing-method
 #' @export
 #' @usage
-#' \S4method{var}{formula,missing,ANY,ANY,missing}(x, y, na.rm=TRUE, use='everything', data=parent.frame())
+#' \S4method{var}{formula,missing,ANY,ANY,missing}(x, y, na.rm=getOption("na.rm",FALSE), use, data)
 setMethod( 
 	"var", 
 	signature=c(x="formula", y="missing", na.rm='ANY', use='ANY', data="missing"),
-	function(x, y, na.rm=TRUE, use='everything', data=parent.frame()) {
-		if(FALSE && .is.simple.formula(x) ) {
-			return( stats::var( eval( .simple.part(x), data ),  na.rm=na.rm, use=use ) )
-		} else {
-			return( maggregate( x, data=data, FUN=stats::var, na.rm=na.rm, use=use) )
-		} 
+	function(x, y, na.rm=getOption("na.rm",FALSE), use, data) {
+		..x <- x
+		if (missing(use)) return( maggregate( ..x, data=parent.frame(2), FUN=var, na.rm=na.rm) )
+		return( maggregate( ..x, data=data, FUN=var, na.rm=na.rm, use=use) )
 	}
 )
 
+#' @rdname aggregating-methods
+### @aliases var,formula,missing,ANY,ANY,environment-method
+#' @export
+#' @usage
+#' \S4method{var}{formula,missing,ANY,ANY,environment}(x, y, na.rm=getOption("na.rm",FALSE), use, data)
+setMethod( 
+	"var", 
+	signature=c(x="formula", y="missing", na.rm='ANY', use='ANY', data="environment"),
+	function(x, y, na.rm=getOption("na.rm",FALSE), use, data) {
+		if (missing(use)) return( maggregate( x, data=data, FUN=var, na.rm=na.rm) )
+		return( maggregate( x, data=data, FUN=var, na.rm=na.rm, use=use) )
+	}
+)
 #' @rdname aggregating-methods
 ### @aliases var,formula,missing,ANY,ANY,data.frame-method
 #' @export
 #' @usage
-#' \S4method{var}{formula,missing,ANY,ANY,data.frame}(x, y, na.rm=TRUE, use='everything', data=parent.frame())
+#' \S4method{var}{formula,missing,ANY,ANY,data.frame}(x, y, na.rm=getOption("na.rm",FALSE), use, data)
 setMethod( 
 	"var", 
 	signature=c(x="formula", y="missing", na.rm='ANY', use='ANY', data="data.frame"),
-	function(x, y, na.rm=TRUE, use='everything', data=parent.frame()) {
-		if(FALSE && .is.simple.formula(x) ) {
-			return( stats::var( eval( .simple.part(x), data ),  na.rm=na.rm, use=use ) )
-		} else {
-			return( maggregate( x, data=data, FUN=stats::var, na.rm=na.rm, use=use) )
-		} 
+	function(x, y, na.rm=getOption("na.rm",FALSE), use, data) {
+		if (missing(use)) return( maggregate( x, data=data, FUN=var, na.rm=na.rm) )
+		return( maggregate( x, data=data, FUN=var, na.rm=na.rm, use=use) )
 	}
 )
 
@@ -624,17 +608,14 @@ setMethod(
 ### @aliases var,formula,data.frame,ANY,ANY,missing-method
 #' @export
 #' @usage
-#' \S4method{var}{formula,data.frame,ANY,ANY,missing}(x, y=parent.frame(), na.rm=FALSE, use='everything')
+#' \S4method{var}{formula,data.frame,ANY,ANY,missing}(x, y=parent.frame(2), na.rm=getOption("na.rm",FALSE), use, data)
 setMethod( 
 	"var", 
 	signature=c(x="formula", y="data.frame", na.rm='ANY', use='ANY', data="missing"),
-	function(x, y=parent.frame(),  na.rm=FALSE, use='everything') {
+	function(x, y=parent.frame(2),  na.rm=getOption("na.rm",FALSE), use, data) {
 		data <- y
-		if(FALSE && .is.simple.formula(x) ) {
-			return( stats::var( eval( .simple.part(x), data),  na.rm=na.rm, use=use ) )
-		} else {
-			return( maggregate( x, data=data, FUN=stats::var, na.rm=na.rm, use=use) )
-		} 
+		if (missing(use)) return( maggregate( x, data=data, FUN=function(z){ stats::var(z, na.rm=na.rm) } ) )
+		return( maggregate( x, data=data, FUN=function(z){ stats::var(z, na.rm=na.rm, use=use) } ) )
 	}
 )
 
@@ -644,7 +625,8 @@ setMethod(
 setMethod( 
 	"var", 
 	signature=c(x="ANY", y="missing", na.rm='ANY', use='ANY', data="data.frame"),
-	function(x,y, na.rm=FALSE, use, data=parent.frame()) {
+	function(x,y, na.rm=getOption("na.rm",FALSE), use, data) {
+		if (missing(use)) return( stats::var( eval( substitute(x), data ), na.rm=na.rm) )
 		return( stats::var( eval( substitute(x), data ), na.rm=na.rm, use=use) )
 	}
 )
@@ -655,7 +637,8 @@ setMethod(
 setMethod( 
 	"var", 
 	signature=c(x="ANY", y="ANY", na.rm='ANY', use='ANY', data="data.frame"),
-	function(x,y, na.rm=FALSE, use, data=parent.frame()) {
+	function(x,y, na.rm=getOption("na.rm",FALSE), use, data) {
+		if(missing(use)) return( stats::var( eval( substitute(x), data ), eval( substitute(y), data ), na.rm=na.rm) )
 		return( stats::var( eval( substitute(x), data ), eval( substitute(y), data ), na.rm=na.rm, use=use) )
 	}
 )
@@ -795,7 +778,7 @@ maggregate <- function(formula, data=parent.frame(), FUN, subset,
 					   format=c('default'), drop=FALSE, multiple=FALSE, ...) {
 	dots <- list(...)
 	format <- match.arg(format)
-	evalF <- evalFormula(formula, data)
+	evalF <- evalFormula(formula, data=data)
   
 	if (!missing(subset)) {
 		subset <- eval(substitute(subset), data, environment(formula))
