@@ -12,17 +12,20 @@
 #' @param breaks,equal.widths,groups,pch,col,lty,lwd,col.line,type,alpha  
 #'     as in \code{\link{histogram}} 
 #'
+#' @param cex  a ratio by which to increase or decrease the dot size
+#'
 #' @param \dots  additional arguments 
 #' 
 #' @return a trellis object
 #'
-#' @author Randall Pruim (\email{rpruim@@calvin.edu})
 #' 
 #' @seealso \code{\link{histogram}}
 #' 
 #' 
 #' @export
 #' @examples
+#' dotPlot( ~ age, data = HELPrct)
+#' dotPlot( ~ age, nint=42, data = HELPrct)
 #' dotPlot( ~ height | voice.part, data = singer, nint = 17,
 #'           endpoints = c(59.5, 76.5), layout = c(2,4), aspect = 1,
 #'           xlab = "Height (inches)")
@@ -32,23 +35,23 @@
 
 dotPlot <-
 function (x, 
-	nint = if (is.factor(x)) nlevels(x) else round(1.3* log2(length(x)) + 4),
 	breaks, ..., panel = panel.dotPlot) 
 {
-    histogram(x, type = "count", panel = panel, nint = nint, breaks = breaks, ...)
+    histogram(x, type = "count", panel = panel, breaks = breaks, ...)
 }
 
-#' @param cex  a ratio by which to increase or decrease the dot size
 #' @rdname dotPlot
 
 panel.dotPlot <-
-function (x, breaks, equal.widths = TRUE, groups = NULL, nint = round(log2(length(x)) + 1), 
+function (x, breaks, equal.widths = TRUE, groups = NULL, 
+	nint = if (is.factor(x)) nlevels(x) else round(1.3* log2(length(x)) + 4),
 	pch = if (is.null(groups)) trellis.par.get("dot.symbol")$pch else trellis.par.get("superpose.symbol")$pch, 
     col = if (is.null(groups)) trellis.par.get("dot.symbol")$col else trellis.par.get("superpose.symbol")$col, 
     lty = trellis.par.get("dot.line")$lty, lwd = trellis.par.get("dot.line")$lwd, 
     col.line = trellis.par.get("dot.line")$col, alpha = trellis.par.get("dot.symbol")$alpha, cex=1, 
     type = "count", ...) 
 {
+	if (is.null(nint)) nint <- if (is.factor(x)) nlevels(x) else round(1.3* log2(length(x)) + 4)
     dot.line <- trellis.par.get("dot.line")
     dot.symbol <- trellis.par.get("dot.symbol")
     sup.symbol <- trellis.par.get("superpose.symbol")
